@@ -40,6 +40,11 @@ class FakePreseemModel:
             if elems is None:
                 elems = FakePreseemModel._elements[company_uuid] = {}
             elems[obj.uuid] = obj
+        for obj in await other.Element.ListElementDiscovery(company_uuid=company_uuid):
+            discs = FakePreseemModel._elem_disc.get(company_uuid)
+            if discs is None:
+                discs = FakePreseemModel._elem_disc[company_uuid] = {}
+            discs[obj.uuid] = obj
         for obj in await other.Site.List(company_uuid=company_uuid):
             sites = FakePreseemModel._sites.get(company_uuid)
             if sites is None:
